@@ -4,20 +4,20 @@ from zope.component import getUtility, queryUtility
 from zope.i18n.interfaces import ITranslationDomain
 from zope.schema.interfaces import IVocabularyFactory
 
-from .interfaces import ITaxonomy
-from .utility import Taxonomy
+from collective.taxonomy.interfaces import ITaxonomy
+from collective.taxonomy.utility import Taxonomy
 
 
-def registerTaxonomy(context, name, title, default_language, description=''):
-    if hasattr(context, 'getSite'):
+def registerTaxonomy(context, name, title, default_language, description=""):
+    if hasattr(context, "getSite"):
         site = context.getSite()
     else:
         site = context
 
     normalizer = getUtility(IIDNormalizer)
 
-    normalized_name = normalizer.normalize(name).replace('-', '')
-    utility_name = 'collective.taxonomy.' + normalized_name
+    normalized_name = normalizer.normalize(name).replace("-", "")
+    utility_name = "collective.taxonomy." + normalized_name
     taxonomy = queryUtility(ITaxonomy, name=utility_name)
 
     if taxonomy is None:
